==> payroll_ver_3.2.1.zip: payroll3/pub/common/js/message.js <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
var msg = new Object();
msg["WU1114"] = "vZȑȌ͑ł܂B";
msg["WU1113"] = "^f[^܂B";
msg["WU1112"] = "vZȑOɖ߂Ƃ͂ł܂B";
msg["WU1111"] = "m̉cƏ݂邽߁Ał܂B";
msg["IC1000"] = "%1%܂B";
msg["WU1106"] = "̃R[h敪͐VKo^ł܂B";
msg["WA1020"] = "R[h͂ĉB";
msg["WU1105"] = "̃f[^́Al}X^邢͐l}X^ŎgpĂ邽߁Aɂł܂B";
msg["WU1104"] = "YΑӏ͑ł܂BxԊOAٓz肳܂B";
msg["WU1103"] = "WvȑO̎x͑ł܂B";
msg["WU1102"] = "xԂdf[^݂邽ߓo^ł܂B";
msg["WU1101"] = "WvŐΑӂ͓͂ł܂B";
msg["WA1011"] = "%1%̃uN͋܂B";
msg["WA1010"] = "uN͋܂B";
msg["QC2021"] = "߂܂B낵łB";
msg["QC2020"] = "F܂B낵łB";
msg["WA1001"] = "Y%1%݂܂B";
msg["WF0043"] = "%1%%2%ɑ΂鏳F܂B";
msg["WC0026"] = "%1%IĂȂЈ݂܂B";
msg["WF0042"] = "%1%ύX܂B";
msg["WC0025"] = "%1%IĂ܂B";
msg["WF0041"] = "%1%߂܂B";
msg["WC0024"] = "Y̎Ј͋^vZΏۊOłB(%1%s)";
msg["WF0040"] = "%1%F܂B";
msg["WC0023"] = "%1%ɂ%2%̓t͂ĂB";
msg["WU2107"] = "ScƏ݂܂B";
msg["WC0022"] = "%1%ɂ͐͂ĂB(%2%s)";
msg["WC0021"] = "%1%%2%ȓœ͂ĂB(%3%s)";
msg["WU2105"] = "Wv̋Αӂ͓͂ł܂B";
msg["WC0020"] = "%1%ɂ͐`̒l͂ĂB(%2%s)";
msg["WU2104"] = "ސE҂̋Αӏ͑ł܂B";
msg["WU2103"] = "Јf[^܂B";
msg["WU2102"] = "Yf[^͍폜Ă܂B";
msg["WU2101"] = "ΑӃf[^܂B";
msg["IC0102"] = "OAEg܂B";
msg["WF0039"] = "Đ\܂B낵łB";
msg["WF0038"] = "XV܂B낵łB";
msg["WF0037"] = "艺܂B낵łB";
msg["WF0036"] = "߂܂B낵łB";
msg["WC0019"] = "wb_dĂ܂B(%1%)";
msg["WF0035"] = "F܂B낵łB";
msg["WC0018"] = "ǂݍރf[^݂܂B";
msg["WF0034"] = "\܂B낵łB";
msg["WC0017"] = "f[^̌`słBmFĂ(%1%s)";
msg["WC0016"] = "wb_̌`słBmFĂ";
msg["WC0015"] = "%1%ǂݍ߂܂BmFĂB";
msg["WC0014"] = "t@C^CvsłBgqucsvv̂݃Abv[h\łB";
msg["WC0013"] = "CSṼwb_ƒl̐słB(%1%s)";
msg["WC0012"] = "̃wb_ł̃Abv[h͑ΏۊOłB(%1%)";
msg["WC0011"] = "%1%͐%2%A%3%ȓ̐lœ͂ĂB";
msg["WC0010"] = "%1%%2%ȏœ͂ĂB";
msg["WC1030"] = "%1%͊ɏFĂ܂";
msg["EH0404"] = "ʐM悪܂B";
msg["WC0009"] = "%1%ɂ͈قȂl͂ĂB";
msg["WF0025"] = "%1%Đ\܂B";
msg["WC0008"] = "%1%ɂ͓l͂ĂB";
msg["WF0024"] = "Đ\܂B";
msg["WC0007"] = "%1%ɂ͐Ԃ͂ĂB";
msg["WF0023"] = "%1%͊Ɏ艺Ă܂B";
msg["WC0006"] = "%1%ɂ͐t͂ĂB";
msg["WF0022"] = "%1%͊ɍ߂Ă܂B";
msg["WC0005"] = "%1%ɂ͐`̒l͂ĂB";
msg["WF0021"] = "%1%͊ɏFĂ܂B";
msg["WC0004"] = "%1%%2%ȓœ͂ĂB";
msg["WF0020"] = "%1%͊ɐ\Ă܂B";
msg["WC0003"] = "%1%ɂ͐͂ĂB";
msg["WC0002"] = "%1%ɂ͔pp͂ĂB";
msg["WC0001"] = "%1%͂ĂB";
msg["WC1029"] = "%1%N%2%%3%͊ɏFĂ܂";
msg["WC1028"] = "%1%N%2%̋ΑӌvZ͊Ă܂";
msg["WC1027"] = "%1%N%2%ߋɂ͖߂܂";
msg["WC1026"] = "%1%N%2%̋^vZ͊Ă܂";
msg["WC1025"] = "%1%N%2%łAȍ~̏͂ł܂";
msg["WC1024"] = "̃f[^͑[U[ɂXVĂ܂Bēxf[^擾čXV{ĂB";
msg["WC1023"] = "̃f[^͊ɓo^Ă܂B";
msg["WF0019"] = "%1%艺ł܂B";
msg["WF0018"] = "%1%\ł܂B";
msg["WF0017"] = "%1%艺܂B";
msg["WF0016"] = "%1%߂܂B";
msg["WF0015"] = "%1%F܂B";
msg["WF0014"] = "%1%\܂B";
msg["WF0013"] = "Ɏ艺Ă܂B";
msg["WF0012"] = "ɍ߂Ă܂B";
msg["WF0011"] = "ɏFĂ܂B";
msg["WF0010"] = "ɐ\Ă܂B";
msg["WC2041"] = "%1%̏oΕɖF܂B";
msg["WC2040"] = "%1%̋ΑӏWvf[^܂B";
msg["WF0009"] = "艺ł܂B";
msg["WC1011"] = "ZbVؒf܂B";
msg["WF0008"] = "\ł܂B";
msg["WF0007"] = "艺܂B";
msg["WF0006"] = "߂܂B";
msg["WF0005"] = "F܂B";
msg["WF0004"] = "\܂B";
msg["WF0003"] = "[Nt[܂B";
msg["WF0002"] = "[Nt[XV܂B";
msg["WF0001"] = "[Nt[o^܂B";
msg["WC2033"] = "%1%̃pX[h܂B";
msg["WC2032"] = "FςLxۗLzĂ܂B";
msg["WC2031"] = "FςƐ\̍vLxۗLzĂ܂B";
msg["WC2030"] = "FςƐ\̍v\nLxۗLzĂ܂B";
msg["WC1007"] = "f[^͂ĂB";
msg["WC1006"] = "YR[h݂܂B";
msg["WC1004"] = "pX[hɌ肪܂B";
msg["WC1003"] = "AJEg̓bNĂ܂BԂučēxOCĂB";
msg["IU0015"] = "o^AKp܂B";
msg["WC1002"] = "[U[ID邢̓pX[hɌ肪܂B";
msg["IU0014"] = "Kp܂B";
msg["IU0013"] = "%1%i߂܂B";
msg["IU0012"] = "%1%߂܂B";
msg["IU0011"] = "%1%܂B";
msg["WC2029"] = "%1%1`60̐l͂ĂB";
msg["WC2028"] = "%1%%2%ȉ͂ĂB";
msg["WC2027"] = "%1%%2%ȏ%3%ȉœ͂ĂB";
msg["WC2026"] = "%1%%2%ȏ͂ĂB";
msg["WC2025"] = "%1%%2%ȓœ͂ĂB";
msg["WC2024"] = "%1%1ȏ͂ĂB";
msg["WC2023"] = "%1%܂B";
msg["WC2022"] = "ߏs܂B";
msg["WC2021"] = "Kꌏ%1%IĂB";
msg["WC2020"] = "%1%F܂B";
msg["QU0015"] = "%1%̊m菈s܂B낵łB";
msg["QU0014"] = "Y%1%f[^폜܂B{ɂ낵łB";
msg["QU0013"] = "Kp㏑o^܂B\n낵łB";
msg["QU0012"] = "%1%ݒ肵܂B\n낵łB";
msg["IC0014"] = "%1%XV܂B";
msg["QU0011"] = "Kp\{ȑO̖KpꊇKp܂B\n낵łB";
msg["IC0013"] = "%1% ` %2% / %3%";
msg["IC0012"] = "Ώۂ%1%݂܂B";
msg["IU0004"] = "%1%%2%B";
msg["IC0011"] = "Ώۃf[^݂܂B";
msg["IU0003"] = "%1%ɎxB";
msg["IU0002"] = "%1%B";
msg["IU0001"] = "%1%ɓB";
msg["WC2019"] = "ɋxɓ͂Ă܂B";
msg["WC2018"] = "%1%N%2%%3%ɏoΏ񂪂܂B";
msg["WC2017"] = "%1%IĂB";
msg["WC2016"] = "݂ĂȂR[h͖ɂł܂B";
msg["WC2015"] = "o^ĂR[hLɂ܂B";
msg["WC2014"] = "o^ĂR[h𖳌ɂ܂B";
msg["WC2013"] = "񎟏Fꊇ܂B";
msg["WC2012"] = "ߋɓo^ꂽڋqR[h͓o^ł܂B";
msg["WC2011"] = "%1%%2%œ͂ĂB";
msg["WC2010"] = "%1%𐳂͂ĂB";
msg["QU0004"] = "%1%̃pX[h܂B낵łB";
msg["QU0003"] = "%1%i߂܂B낵łB";
msg["IC0006"] = "YЈ̐l{񂪑݂܂B(%1%s)";
msg["QU0002"] = "%1%߂܂B낵łB";
msg["IC0005"] = "%1%CSVf[^Abv[h܂";
msg["QU0001"] = "%1%܂B낵łB";
msg["IC0004"] = "폜܂B";
msg["IC0003"] = "łB";
msg["IC0002"] = "XV܂B";
msg["IC0001"] = "o^܂B";
msg["IC0000"] = "܂B";
msg["EC0002"] = "VXeG[܂B";
msg["EC0001"] = "ʐMɎs܂B";
msg["QC0002"] = "폜܂B{ɂ낵łB";
msg["WA1999"] = "f[^͂ĉB";
msg["QC0001"] = "o^܂B낵łB";
msg["WU1121"] = "%1%N%2%̋^f[^܂Bm菈IĂB";
msg["WU1120"] = "ܗ^f[^܂";
msg["EH0500"] = "T[o[ŃG[܂B";
msg["WC0102"] = "|bvAbvubNĂ\܂B\n_CAO\Ȃꍇ́ÃTCg̃|bvAbv悤ɃuEUݒ肵ĂB";
msg["WC0101"] = "ZbVؒf܂B\nēxOCĂB";
msg["WU1119"] = "s݂邽߁Amł܂B";
msg["WU1118"] = "vZŐ^ׂ͕ҏWł܂B";
msg["WU1117"] = "l𑼃[U[(%1%)ҏWĂ\܂B";
msg["WU1116"] = "YЈ̐l{񂪑݂܂B";
msg["WU1115"] = "ꊇKpΏ({ȑOvZJnȍ~̖Kp)݂܂B";

==> payroll_ver_3.3.0.zip: payroll3/pub/common/js/message.js <==
var msg = new Object();
msg["WU1114"] = "vZȑȌ͑ł܂B";
msg["WU1113"] = "^f[^܂B";
msg["WU1112"] = "vZȑOɖ߂Ƃ͂ł܂B";
msg["WU1111"] = "m̉cƏ݂邽߁Ał܂B";
msg["IC1000"] = "%1%܂B";
msg["WU1106"] = "̃R[h敪͐VKo^ł܂B";
msg["WA1020"] = "R[h͂ĉB";
msg["WU1105"] = "̃f[^́Al}X^邢͐l}X^ŎgpĂ邽߁Aɂł܂B";
msg["WU1104"] = "YΑӏ͑ł܂BxԊOAٓz肳܂B";
msg["WU1103"] = "WvȑO̎x͑ł܂B";
msg["WU1102"] = "xԂdf[^݂邽ߓo^ł܂B";
msg["WU1101"] = "WvŐΑӂ͓͂ł܂B";
msg["WA1011"] = "%1%̃uN͋܂B";
msg["WA1010"] = "uN͋܂B";
msg["QC2021"] = "߂܂B낵łB";
msg["QC2020"] = "F܂B낵łB";
msg["WA1001"] = "Y%1%݂܂B";
msg["WC0028"] = "%1%ɂ%2%O̓t͂ĂB";
msg["WC0027"] = "t@Cɂăf[^dĂ܂B";
msg["WF0043"] = "%1%%2%ɑ΂鏳F܂B";
msg["WC0026"] = "%1%IĂȂЈ݂܂B";
msg["WF0042"] = "%1%ύX܂B";
msg["WC0025"] = "%1%IĂ܂B";
msg["WF0041"] = "%1%߂܂B";
msg["WC0024"] = "Y̎Ј͋^vZΏۊOłB(%1%s)";
msg["WF0040"] = "%1%F܂B";
msg["WC0023"] = "%1%ɂ%2%̓t͂ĂB";
msg["WU2107"] = "ScƏ݂܂B";
msg["WC0022"] = "%1%ɂ͐͂ĂB(%2%s)";
msg["WC0021"] = "%1%%2%ȓœ͂ĂB(%3%s)";
msg["WU2105"] = "Wv̋Αӂ͓͂ł܂B";
msg["WC0020"] = "%1%ɂ͐`̒l͂ĂB(%2%s)";
msg["WU2104"] = "ސE҂̋Αӏ͑ł܂B";
msg["WU2103"] = "Јf[^܂B";
msg["WU2102"] = "Yf[^͍폜Ă܂B";
msg["WU2101"] = "ΑӃf[^܂B";
msg["IC0102"] = "OAEg܂B";
msg["WF0039"] = "Đ\܂B낵łB";
msg["WF0038"] = "XV܂B낵łB";
msg["WF0037"] = "艺܂B낵łB";
msg["WF0036"] = "߂܂B낵łB";
msg["WC0019"] = "wb_dĂ܂B(%1%)";
msg["WF0035"] = "F܂B낵łB";
msg["WC0018"] = "ǂݍރf[^݂܂B";
msg["WF0034"] = "\܂B낵łB";
msg["WC0017"] = "f[^̌`słBmFĂ(%1%s)";
msg["WC0016"] = "wb_̌`słBmFĂ";
msg["WC0015"] = "%1%ǂݍ߂܂BmFĂB";
msg["WC0014"] = "t@C^CvsłBgqucsvv̂݃Abv[h\łB";
msg["WC0013"] = "CSṼwb_ƒl̐słB(%1%s)";
msg["WC0012"] = "̃wb_ł̃Abv[h͑ΏۊOłB(%1%)";
msg["WC0011"] = "%1%͐%2%A%3%ȓ̐lœ͂ĂB";
msg["WC0010"] = "%1%%2%ȏœ͂ĂB";
msg["WC1030"] = "%1%͊ɏFĂ܂";
msg["EH0404"] = "ʐM悪܂B";
msg["WF0026"] = "%1%߂ł܂B";
msg["WC0009"] = "%1%ɂ͈قȂl͂ĂB";
msg["WF0025"] = "%1%Đ\܂B";
msg["WC0008"] = "%1%ɂ͓l͂ĂB";
msg["WF0024"] = "Đ\܂B";
msg["WC0007"] = "%1%ɂ͐Ԃ͂ĂB";
msg["WF0023"] = "%1%͊Ɏ艺Ă܂B";
msg["WC0006"] = "%1%ɂ͐t͂ĂB";
msg["WF0022"] = "%1%͊ɍ߂Ă܂B";
msg["WC0005"] = "%1%ɂ͐`̒l͂ĂB";
msg["WF0021"] = "%1%͊ɏFĂ܂B";
msg["WC0004"] = "%1%%2%ȓœ͂ĂB";
msg["WF0020"] = "%1%͊ɐ\Ă܂B";
msg["WC0003"] = "%1%ɂ͐͂ĂB";
msg["WC0002"] = "%1%ɂ͔pp͂ĂB";
msg["WC0001"] = "%1%͂ĂB";
msg["WC2056"] = "%1%%2%̗Lxɕs܂B";
msg["WC2055"] = "%1%%2%̐\ԈĂ܂B";
msg["WC2054"] = "%1%%2%̗\肪܂B";
msg["WC2053"] = "%1%%2%ɂLx񂪂܂B";
msg["WC2052"] = "cԂ}CiX͓̂̂o^ł܂B";
msg["WC2051"] = "%1%%2%ɂ֋xɂۗ̕LzĂ܂B";
msg["WC2050"] = "%1%%2%ɂLxۗ̕LzĂ܂B";
msg["WC1029"] = "%1%N%2%%3%͊ɏFĂ܂";
msg["WC1028"] = "%1%N%2%̋ΑӌvZ͊Ă܂";
msg["WC1027"] = "%1%N%2%ߋɂ͖߂܂";
msg["WC1026"] = "%1%N%2%̋^vZ͊Ă܂";
msg["WC1025"] = "%1%N%2%łAȍ~̏͂ł܂";
msg["WC1024"] = "̃f[^͑[U[ɂXVĂ܂Bēxf[^擾čXV{ĂB";
msg["WC1023"] = "̃f[^͊ɓo^Ă܂B";
msg["WF0019"] = "%1%艺ł܂B";
msg["WF0018"] = "%1%\ł܂B";
msg["WF0017"] = "%1%艺܂B";
msg["WF0016"] = "%1%߂܂B";
msg["WF0015"] = "%1%F܂B";
msg["WF0014"] = "%1%\܂B";
msg["WF0013"] = "Ɏ艺Ă܂B";
msg["WF0012"] = "ɍ߂Ă܂B";
msg["WF0011"] = "ɏFĂ܂B";
msg["WF0010"] = "ɐ\Ă܂B";
msg["WC2041"] = "%1%̏oΕɖF܂B";
msg["WC2040"] = "%1%̋ΑӏWvf[^܂B";
msg["WF0009"] = "艺ł܂B";
msg["WC1011"] = "ZbVؒf܂B";
msg["WF0008"] = "\ł܂B";
msg["WF0007"] = "艺܂B";
msg["WF0006"] = "߂܂B";
msg["WF0005"] = "F܂B";
msg["WF0004"] = "\܂B";
msg["WF0003"] = "[Nt[܂B";
msg["WF0002"] = "[Nt[XV܂B";
msg["WF0001"] = "[Nt[o^܂B";
msg["WC2033"] = "%1%̃pX[h܂B";
msg["WC2032"] = "FςLxۗLzĂ܂B";
msg["WC2031"] = "FςƐ\̍vLxۗLzĂ܂B";
msg["WC2030"] = "FςƐ\̍v\nLxۗLzĂ܂B";
msg["WC1007"] = "f[^͂ĂB";
msg["WC1006"] = "YR[h݂܂B";
msg["WC1004"] = "pX[hɌ肪܂B";
msg["WC1003"] = "AJEg̓bNĂ܂BԂučēxOCĂB";
msg["IU0015"] = "o^AKp܂B";
msg["WC1002"] = "[U[ID邢̓pX[hɌ肪܂B";
msg["IU0014"] = "Kp܂B";
msg["IU0013"] = "%1%i߂܂B";
msg["IU0012"] = "%1%߂܂B";
msg["IU0011"] = "%1%܂B";
msg["WC2029"] = "%1%1`60̐l͂ĂB";
msg["WC2028"] = "%1%%2%ȉ͂ĂB";
msg["WC2027"] = "%1%%2%ȏ%3%ȉœ͂ĂB";
msg["WC2026"] = "%1%%2%ȏ͂ĂB";
msg["WC2025"] = "%1%%2%ȓœ͂ĂB";
msg["WC2024"] = "%1%1ȏ͂ĂB";
msg["WC2023"] = "%1%܂B";
msg["WC2022"] = "ߏs܂B";
msg["WC2021"] = "Kꌏ%1%IĂB";
msg["WC2020"] = "%1%F܂B";
msg["QU0015"] = "%1%̊m菈s܂B낵łB";
msg["QU0014"] = "Y%1%f[^폜܂B{ɂ낵łB";
msg["QU0013"] = "Kp㏑o^܂B\n낵łB";
msg["QU0012"] = "%1%ݒ肵܂B\n낵łB";
msg["IC0014"] = "%1%XV܂B";
msg["QU0011"] = "Kp\{ȑO̖KpꊇKp܂B\n낵łB";
msg["IC0013"] = "%1% ` %2% / %3%";
msg["IC0012"] = "Ώۂ%1%݂܂B";
msg["IU0004"] = "%1%%2%B";
msg["IC0011"] = "Ώۃf[^݂܂B";
msg["IU0003"] = "%1%ɎxB";
msg["IU0002"] = "%1%B";
msg["IU0001"] = "%1%ɓB";
msg["WC2019"] = "ɋxɓ͂Ă܂B";
msg["WC2018"] = "%1%N%2%%3%ɏoΏ񂪂܂B";
msg["WC2017"] = "%1%IĂB";
msg["WC2016"] = "݂ĂȂR[h͖ɂł܂B";
msg["WC2015"] = "o^ĂR[hLɂ܂B";
msg["WC2014"] = "o^ĂR[h𖳌ɂ܂B";
msg["WC2013"] = "񎟏Fꊇ܂B";
msg["WC2012"] = "ߋɓo^ꂽڋqR[h͓o^ł܂B";
msg["WC2011"] = "%1%%2%œ͂ĂB";
msg["WC2010"] = "%1%𐳂͂ĂB";
msg["QU0004"] = "%1%̃pX[h܂B낵łB";
msg["QU0003"] = "%1%i߂܂B낵łB";
msg["IC0006"] = "YЈ̐l{񂪑݂܂B(%1%s)";
msg["QU0002"] = "%1%߂܂B낵łB";
msg["IC0005"] = "%1%CSVf[^Abv[h܂";
msg["QU0001"] = "%1%܂B낵łB";
msg["IC0004"] = "폜܂B";
msg["IC0003"] = "łB";
msg["IC0002"] = "XV܂B";
msg["IC0001"] = "o^܂B";
msg["IC0000"] = "܂B";
msg["EC0002"] = "VXeG[܂B";
msg["EC0001"] = "ʐMɎs܂B";
msg["QC0002"] = "폜܂B{ɂ낵łB";
msg["QC0001"] = "o^܂B낵łB";
msg["WA1999"] = "f[^͂ĉB";
msg["WU1121"] = "%1%N%2%̋^f[^܂Bm菈IĂB";
msg["WU1120"] = "ܗ^f[^܂";
msg["EH0500"] = "T[o[ŃG[܂B";
msg["WC0102"] = "|bvAbvubNĂ\܂B\n_CAO\Ȃꍇ́ÃTCg̃|bvAbv悤ɃuEUݒ肵ĂB";
msg["WC0101"] = "ZbVؒf܂B\nēxOCĂB";
msg["WU1119"] = "s݂邽߁Amł܂B";
msg["WU1118"] = "vZŐ^ׂ͕ҏWł܂B";
msg["WU1117"] = "l𑼃[U[(%1%)ҏWĂ\܂B";
msg["WU1116"] = "YЈ̐l{񂪑݂܂B";
msg["WU1115"] = "ꊇKpΏ({ȑOvZJnȍ~̖Kp)݂܂B";
